@@ -23,8 +23,23 @@ class writer(file_writer):
             append = False
 
         self.buffering = buffering
-        self.mode: str = "ab" if append else "wb"
-        self.metadata = metadata
+
+        if append:
+            self.mode = "ab"
+            self.header = None
+        else:
+            self.mode = "wb"
+            width = metadata["width"]
+            height = metadata["height"]
+            self.header = f"\x1b[8;{height};{width}t".encode("utf-8")
+
+    def __enter__(self) -> Any:
+        super().__enter__()
+
+        if self.header:
+            self._write(self.header)
+
+        return self
 
     def write_stdout(self, _ts: float, data: Any) -> None:
         self._write(data)
@@ -33,6 +48,9 @@ class writer(file_writer):
     def write_stdin(self, ts: float, data: Any) -> None:
         pass
 
+    def write_marker(self, ts: float) -> None:
+        pass
+
     # pylint: disable=consider-using-with
     def _open_file(self) -> None:
         if self.path == "-":
